You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flink.apache.org by ch...@apache.org on 2017/07/12 15:21:03 UTC

flink git commit: [FLINK-6965] Include snappy-java in flink-dist

Repository: flink
Updated Branches:
  refs/heads/release-1.3 5ace91a08 -> aaa7df55c


[FLINK-6965] Include snappy-java in flink-dist


Project: http://git-wip-us.apache.org/repos/asf/flink/repo
Commit: http://git-wip-us.apache.org/repos/asf/flink/commit/aaa7df55
Tree: http://git-wip-us.apache.org/repos/asf/flink/tree/aaa7df55
Diff: http://git-wip-us.apache.org/repos/asf/flink/diff/aaa7df55

Branch: refs/heads/release-1.3
Commit: aaa7df55ceb741ca4dd886e8816ddbab58afb078
Parents: 5ace91a
Author: zentol <ch...@apache.org>
Authored: Wed Jun 21 16:18:34 2017 +0200
Committer: zentol <ch...@apache.org>
Committed: Wed Jul 12 12:16:30 2017 +0200

----------------------------------------------------------------------
 flink-core/pom.xml           | 13 ++++++-------
 pom.xml                      |  6 ++++++
 tools/travis_mvn_watchdog.sh |  9 ++++++++-
 3 files changed, 20 insertions(+), 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flink/blob/aaa7df55/flink-core/pom.xml
----------------------------------------------------------------------
diff --git a/flink-core/pom.xml b/flink-core/pom.xml
index 1efcb29..7daa840 100644
--- a/flink-core/pom.xml
+++ b/flink-core/pom.xml
@@ -79,13 +79,12 @@ under the License.
 		<dependency>
 			<groupId>org.apache.avro</groupId>
 			<artifactId>avro</artifactId>
-			<!-- managed version -->
-			<exclusions>
-				<exclusion>
-					<groupId>org.xerial.snappy</groupId>
-					<artifactId>snappy-java</artifactId>
-				</exclusion>
-			</exclusions>
+		</dependency>
+
+		<!-- We explicitly depend on snappy since connectors that require it load it through the system class loader -->
+		<dependency>
+			<groupId>org.xerial.snappy</groupId>
+			<artifactId>snappy-java</artifactId>
 		</dependency>
 
 		<!-- ASM is needed for type extraction -->

http://git-wip-us.apache.org/repos/asf/flink/blob/aaa7df55/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 915f572..2806f4a 100644
--- a/pom.xml
+++ b/pom.xml
@@ -261,6 +261,12 @@ under the License.
 				<version>1.7.7</version>
 			</dependency>
 
+			<dependency>
+				<groupId>org.xerial.snappy</groupId>
+				<artifactId>snappy-java</artifactId>
+				<version>1.0.5</version>
+			</dependency>
+
 			<!-- Make sure we use a consistent commons-cli version throughout the project -->
 			<dependency>
 				<groupId>commons-cli</groupId>

http://git-wip-us.apache.org/repos/asf/flink/blob/aaa7df55/tools/travis_mvn_watchdog.sh
----------------------------------------------------------------------
diff --git a/tools/travis_mvn_watchdog.sh b/tools/travis_mvn_watchdog.sh
index e2c38d4..08fa423 100755
--- a/tools/travis_mvn_watchdog.sh
+++ b/tools/travis_mvn_watchdog.sh
@@ -164,7 +164,7 @@ watchdog () {
 	done
 }
 
 # Check the final fat jar for illegal artifacts
 check_shaded_artifacts() {
 	jar tf build-target/lib/flink-dist*.jar > allClasses
 	ASM=`cat allClasses | grep '^org/objectweb/asm/' | wc -l`
@@ -183,6 +183,13 @@ check_shaded_artifacts() {
 		exit 1
 	fi
 
+	SNAPPY=`cat allClasses | grep '^org/xerial/snappy' | wc -l`
+	if [ $SNAPPY == "0" ]; then
+		echo "=============================================================================="
+		echo "Missing snappy dependencies in fat jar"
+		echo "=============================================================================="
+		exit 1
+	fi
 }
 
 # =============================================================================
@@ -164,7 +164,7 @@ watchdog () {
 }
 
-# Check the final fat jar for illegal artifacts
+# Check the final fat jar for illegal or missing artifacts
 check_shaded_artifacts() {
 	jar tf build-target/lib/flink-dist*.jar > allClasses